@@ -17,7 +17,7 @@ stplot.STIDF = function(obj, names.attr = index(obj@time), ...)
 stplot.STIDF = function(obj, names.attr = NULL, ..., 
 		as.table = TRUE, by = c("time", "burst", "id"), 
 		scales = list(draw=FALSE), xlab = NULL, ylab = NULL, 
-		type = type, number = 6, overlap = 0, asp) {
+		type = 'p', number = 6, overlap = 0, asp) {
 	f =  paste(rev(coordnames(obj@sp)), collapse="~")
 	by = by[1]
 	f = paste(f, "|", by)
@@ -26,7 +26,7 @@ stplot.STIDF = function(obj, names.attr = NULL, ...,
 	obj = as.data.frame(obj)
 	if (is.numeric(number) && number > 1)
 		obj$time = equal.count(obj$time, number = number, overlap = overlap)
-	xyplot(as.formula(f), obj, asp = asp, type='l',
+	xyplot(as.formula(f), obj, asp = asp, type = type,
 		as.table = as.table, scales = scales, xlab = xlab, ylab = ylab, 
 		...)
 }
